@@ -58,6 +58,14 @@ RSpec.describe "a matcher defined using the matcher DSL" do
       expect(1).to match_optional_kw(bar: 1)
     end
 
+    # This is a regression test for rspec/rspec#145
+    it 'supports the use of optional keyword arguments in definition block when passed a hash' do
+      RSpec::Matchers.define(:match_optional_kw_hash) do |hash, bar: nil|
+        match { expect(hash["1"]).to eq 1 }
+      end
+      expect(1).to match_optional_kw_hash({"1" => 1})
+    end
+
     def optional_kw(a: nil)
       a
     end
@@ -515,8 +523,10 @@ module RSpec::Matchers::DSL
 
       if Diff::LCS::VERSION.to_f < 1.4
         expected_diff = "Diff:\n@@ -1,3 +1,3 @@\n-line1\n+LINE1\nline2\n"
-      else
+      elsif Diff::LCS::VERSION.to_f < 1.6
         expected_diff = "Diff:\n@@ -1 +1 @@\n-line1\n+LINE1\n"
+      else
+        expected_diff = "Diff:\n@@ -1,2 +1,2 @@\n-line1\n+LINE1\nline2\n"
       end
 
       expect(diff).to eq expected_diff
